@@ -162,6 +162,7 @@ keywords = (
     'idproperty',
     'rhythmdictation',
     'rhythmdictation2',
+    'toneincontext',
     'tuner',
     #
     'harmonic',
@@ -1903,13 +1904,20 @@ class InfoCache(object):
                     except self.InfoCacheException:
                         logging.debug(" exception, not parsed: %s", fn)
                         pass
-    def iter_user_files(self):
+    def iter_user_files(self, only_user_collection=False):
         """
         Put the data from the lesson files below ~/.solfege/exercises/
         in the cache and yield the filename.
+        
+        If only_user_collection=True it will only iterate the lesson files
+        in .solfege/exercises/user/lesson-files
         """
-        logging.debug("iter_user_files()")
-        for fn in glob.glob(os.path.join(filesystem.user_data(), u"exercises/*/*/*")):
+        logging.debug("iter_user_files(%s)", only_user_collection)
+        if only_user_collection:
+            mask = u"user/lesson-files/*"
+        else:
+            mask = u"*/*/*"
+        for fn in glob.glob(os.path.join(filesystem.user_data(), u"exercises", mask)):
             if os.path.isfile(fn):
                 try:
                     self.parse_file(fn)
